using SellmeierFit
using SimpleConstants  # for micro = 1e-6
using CairoMakie

## Main section
# Load a set of measured refractive index data from Malitson.txt.
filepath = joinpath(@__DIR__, "data", "Malitson.txt")
(; λ, ε) = SellmeierFit.read(filepath, header=2)

# Fit the loaded data to the Sellmeier equation.
(; mdl, err) = fit_sellmeier(λ, ε)
# To perform loading and fitting data at once, do
#     (; mdl, err) = fit_sellmeier(filepath)

## Analysis section
# The calculated fit parameters are the same as those shown in RefractiveIndex.INFO's
# Dispersion formula section.
println("B = $(mdl.str)")
println("√C (µm) = $(mdl.λres ./ micro)")
println("Error between data and fit = $err")

# Visualize the measured data and fit Sellmeier equation; note that n = √ε.
fontsize = 20
fig = Figure(; fontsize)
fig[1,1] = Axis(fig, title="Refractive Index of SiO₂", xlabel="λ (meter)", ylabel="n")
scatter!(λ, .√ε, label="Measurement", color=:black)
lines!(λ, .√mdl.(λ), label="Sellmeier equation", color=:red)
axislegend(; position=:rt)
display(fig)
