using SellmeierFit
using SimpleConstants  # for micro = 1e-6 and nano = 1e-9
using CairoMakie

## Main section
# Load a set of measured refractive index data from https://RefractiveIndex.Info.
(; λ, ε) = SellmeierFit.read(RefractiveIndexInfo("Si", "Aspnes"))

# Fit the loaded data to the Sellmeier equation.  Because silicon is lossy, let the fitting
# procedure take only the lossless wavelength range between λmin and λmax. (The default
# values λmin and λmax are -Inf and Inf, respectively.)
λmin = 400nano
(; mdl, err) = fit_sellmeier(λ, ε; λmin)

## Analysis section
# The calculated fit parameters are the same as those shown in RefractiveIndex.INFO's
# Dispersion formula section.
println("B = $(mdl.str)")
println("√C (µm) = $(mdl.λres ./ micro)")
println("Error between data and fit = $err")

# Visualize the measured data and fit Sellmeier equation; note that n = √ε.
fontsize = 20
fig = Figure(; fontsize)
fig[1,1] = Axis(fig, title="Refractive Index of SiO₂", xlabel="λ (meter)", ylabel="n")
scatter!(λ, .√ε, label="Measurement", color=:black)
λplot = range(λmin, λ[end], length=100)
lines!(λplot, .√mdl.(λplot), label="Sellmeier equation", color=:red)
axislegend(; position=:rt)
display(fig)
