# Same as example/from_csv.jl, but without the time-consuming plot.

using SellmeierFit
using SimpleConstants  # for micro = 1e-6

## Main section
# Load a set of measured refractive index data from Malitson.csv
filepath = joinpath(@__DIR__, "data", "Malitson.csv")
(; λ, ε) = SellmeierFit.read(filepath)

# Fit the loaded data to the Sellmeier equation.
(; mdl, err) = fit_sellmeier(λ, ε)
# To perform loading and fitting data at once, do
#     (; mdl, err) = fit_sellmeier(filepath)

## Analysis section
# The calculated fit parameters are the same as those shown in RefractiveIndex.INFO's
# Dispersion formula section.
println("B = $(mdl.str)")
println("√C (µm) = $(mdl.λres ./ micro)")
println("Error between data and fit = $err")
